# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['muenster']

package_data = \
{'': ['*']}

install_requires = \
['aiohttp>=3.0.0', 'pyproj>=3.3.1,<4.0.0', 'yarl>=1.6.0']

setup_kwargs = {
    'name': 'muenster',
    'version': '0.1.0',
    'description': 'Asynchronous Python client providing Open Data information of Muenster',
    'long_description': '## Python - ODP Muenster Client\n\n<!-- PROJECT SHIELDS -->\n[![GitHub Release][releases-shield]][releases]\n[![Python Versions][python-versions-shield]][pypi]\n![Project Stage][project-stage-shield]\n![Project Maintenance][maintenance-shield]\n[![License][license-shield]](LICENSE)\n\n[![GitHub Activity][commits-shield]][commits-url]\n[![Forks][forks-shield]][forks-url]\n[![Stargazers][stars-shield]][stars-url]\n[![Issues][issues-shield]][issues-url]\n[![GitHub Last Commit][last-commit-shield]][commits-url]\n\n[![Code Quality][code-quality-shield]][code-quality]\n[![Maintainability][maintainability-shield]][maintainability-url]\n[![Code Coverage][codecov-shield]][codecov-url]\n\n[![Build Status][build-shield]][build-url]\n[![Typing Status][typing-shield]][typing-url]\n\nAsynchronous Python client for the open datasets of Muenster (Germany).\n\n## About\n\nA python package with which you can retrieve data from the Open Data Platform of Muenster via [their API][api]. This package was initially created to only retrieve parking data from the API, but the code base is made in such a way that it is easy to extend for other datasets from the same platform.\n\n## Installation\n\n```bash\npip install muenster\n```\n\n## Datasets\n\nYou can read the following datasets with this package:\n\n- [Garages / Parkleitsystem][garages] (16 locations)\n\n<details>\n    <summary>Click here to get more details</summary>\n\n### Garages\n\nParameters:\n\n- **limit** (default: 10) - How many results you want to retrieve.\n\n| Variable | Type | Description |\n| :------- | :--- | :---------- |\n| `name` | string | The name of the garage |\n| `status` | string | The status of the garage |\n| `parking_type` | string | The type of parking of the garage (**Parkplatz** or **Parkhaus**) |\n| `free_space` | integer | The free space of the garage |\n| `total_capacity` | integer | The total capacity of the garage |\n| `availability_pct` | float | The availability percentage of the garage |\n| `url` | string | The URL with more information of the garage |\n| `longitude` | float | The longitude of the garage |\n| `latitude` | float | The latitude of the garage |\n</details>\n\n## Example\n\n```python\nimport asyncio\n\nfrom muenster import StadtMuenster\n\n\nasync def main() -> None:\n    """Show example on using the API of Muenster."""\n    async with StadtMuenster() as client:\n        garages = await client.garages(limit=10)\n        print(garages)\n\n\nif __name__ == "__main__":\n    asyncio.run(main())\n```\n\n## Use cases\n\n[NIPKaart.nl][nipkaart]\n\nA website that provides insight into where disabled parking spaces are, based\non data from users and municipalities. Operates mainly in the Netherlands, but\nalso has plans to process data from abroad.\n\n## Contributing\n\nThis is an active open-source project. We are always open to people who want to\nuse the code or contribute to it.\n\nWe\'ve set up a separate document for our\n[contribution guidelines](CONTRIBUTING.md).\n\nThank you for being involved! :heart_eyes:\n\n## Setting up development environment\n\nThis Python project is fully managed using the [Poetry][poetry] dependency\nmanager.\n\nYou need at least:\n\n- Python 3.9+\n- [Poetry][poetry-install]\n\nInstall all packages, including all development requirements:\n\n```bash\npoetry install\n```\n\nPoetry creates by default an virtual environment where it installs all\nnecessary pip packages, to enter or exit the venv run the following commands:\n\n```bash\npoetry shell\nexit\n```\n\nSetup the pre-commit check, you must run this inside the virtual environment:\n\n```bash\npre-commit install\n```\n\n*Now you\'re all set to get started!*\n\nAs this repository uses the [pre-commit][pre-commit] framework, all changes\nare linted and tested with each commit. You can run all checks and tests\nmanually, using the following command:\n\n```bash\npoetry run pre-commit run --all-files\n```\n\nTo run just the Python tests:\n\n```bash\npoetry run pytest\n```\n\n## License\n\nMIT License\n\nCopyright (c) 2022 Klaas Schoute\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the "Software"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.\n\n[api]: https://opendata.stadt-muenster.de\n[garages]: https://opendata.stadt-muenster.de/dataset/parkleitsystem-parkhausbelegung-aktuell\n[nipkaart]: https://www.nipkaart.nl\n\n<!-- MARKDOWN LINKS & IMAGES -->\n[build-shield]: https://github.com/klaasnicolaas/python-muenster/actions/workflows/tests.yaml/badge.svg\n[build-url]: https://github.com/klaasnicolaas/python-muenster/actions/workflows/tests.yaml\n[code-quality-shield]: https://img.shields.io/lgtm/grade/python/g/klaasnicolaas/python-muenster.svg?logo=lgtm&logoWidth=18\n[code-quality]: https://lgtm.com/projects/g/klaasnicolaas/python-muenster/context:python\n[commits-shield]: https://img.shields.io/github/commit-activity/y/klaasnicolaas/python-muenster.svg\n[commits-url]: https://github.com/klaasnicolaas/python-muenster/commits/main\n[codecov-shield]: https://codecov.io/gh/klaasnicolaas/python-muenster/branch/main/graph/badge.svg?token=OZgV3Ib3Er\n[codecov-url]: https://codecov.io/gh/klaasnicolaas/python-muenster\n[forks-shield]: https://img.shields.io/github/forks/klaasnicolaas/python-muenster.svg\n[forks-url]: https://github.com/klaasnicolaas/python-muenster/network/members\n[issues-shield]: https://img.shields.io/github/issues/klaasnicolaas/python-muenster.svg\n[issues-url]: https://github.com/klaasnicolaas/python-muenster/issues\n[license-shield]: https://img.shields.io/github/license/klaasnicolaas/python-muenster.svg\n[last-commit-shield]: https://img.shields.io/github/last-commit/klaasnicolaas/python-muenster.svg\n[maintenance-shield]: https://img.shields.io/maintenance/yes/2022.svg\n[maintainability-shield]: https://api.codeclimate.com/v1/badges/cb6cb45c337d037071b7/maintainability\n[maintainability-url]: https://codeclimate.com/github/klaasnicolaas/python-muenster/maintainability\n[project-stage-shield]: https://img.shields.io/badge/project%20stage-experimental-yellow.svg\n[pypi]: https://pypi.org/project/muenster/\n[python-versions-shield]: https://img.shields.io/pypi/pyversions/muenster\n[typing-shield]: https://github.com/klaasnicolaas/python-muenster/actions/workflows/typing.yaml/badge.svg\n[typing-url]: https://github.com/klaasnicolaas/python-muenster/actions/workflows/typing.yaml\n[releases-shield]: https://img.shields.io/github/release/klaasnicolaas/python-muenster.svg\n[releases]: https://github.com/klaasnicolaas/python-muenster/releases\n[stars-shield]: https://img.shields.io/github/stars/klaasnicolaas/python-muenster.svg\n[stars-url]: https://github.com/klaasnicolaas/python-muenster/stargazers\n\n[poetry-install]: https://python-poetry.org/docs/#installation\n[poetry]: https://python-poetry.org\n[pre-commit]: https://pre-commit.com\n',
    'author': 'Klaas Schoute',
    'author_email': 'hello@student-techlife.com',
    'maintainer': 'Klaas Schoute',
    'maintainer_email': 'hello@student-techlife.com',
    'url': 'https://github.com/klaasnicolaas/python-muenster',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
